import React, { Component } from 'react';
import { isArray, cloneDeep } from 'lodash';
import styles from './block-preview.css'
import withStyles from 'isomorphic-style-loader/lib/withStyles';

/**
 * This component will be responsible for rendering HTML blocks
 */
class BlockPreview extends Component {

    
    constructor(props) {
        super(props);
        
        this.state = {
            currentBlock: null
        }
    }

    componentDidMount() {

        console.log('[block-preview] block content is', cloneDeep(this.blockContent));

        window.addEventListener('message', this.listenForMessages.bind(this));

        window.top.postMessage([{
            channel: 'blockPreviewOnInit',
            message: 'ready'
        }], this.props.targetOrigin || "*" );
        
        window.top.postMessage([{
            channel: 'OnInit',
            message: true
        }], this.props.targetOrigin || "*" );
    }

    listenForMessages = (e) => {
        // We want to check if the data is an array, otherwise we are receiving post message in a different context
        // than the one we are used to for example storybook sends messages where data equals a string. 
        //
        if ( isArray(e.data) ) {
            e.data.forEach(data => {
                if (data.channel === 'blockChange') {
                    this.setState({
                        currentBlock: data.message
                    });
                }
            });
        } else {
            console.warn('[block-preview] received data but it wasnt of type array');
        }
    }

    componentWillUnmount() {
        // When the component unmounts, the iframe will be destroyed. So technically we don't need to write clean up logic.
        //
        window.removeEventListener('message', this.listenForMessages);
    }

    /**
     * Returns an object dangerouslySetInnerHTML can render
     * @param {string} html - the text you want to render
     */
    createMarkup(html) {
        return { __html: html };
    }


    render() {
        if ( !this.state.currentBlock ) {
            return <span>loading...</span>
        }

        return (
            <div className={styles.BlockPreview}>
                <style dangerouslySetInnerHTML={this.createMarkup(this.state.currentBlock.CssStyles)}>
                </style>
                <div className={`preview-block ${this.state.currentBlock.ID} ${this.state.currentBlock.CssClasses.join(' ') || []}`} 
                    dangerouslySetInnerHTML={this.createMarkup(this.state.currentBlock.Template)}>
                </div>
            </div>
        )
        
    }
}

export default withStyles(styles)(BlockPreview);
