import React, { Component } from 'react';
import styles from './renderer.css';
import Counter  from '../counter/counter';
import Header from '../header/header';
import VisualBlock from '../visual-block/visual-block';
import withStyles from 'isomorphic-style-loader/lib/withStyles';
import { get } from 'lodash';

class Renderer extends Component {


    get components() {
        return this.props.components || {};
    }

    static defaultProps = {
        page: null,
        endPointUrl: null
    }
    componentDidMount() {
        console.log('[renderer] props are ', this.props);

        if ( this.props.endPointUrl ) {
            if ( !this.props.page ) {
                console.error('[makeup:renderer] no page was provided as prop');
            }
        } else {
            console.error('[makeup:renderer] no end point url was provided as prop');
        }
    }


    render() {
        /** The css classes of this page */
        const pageClasses = get(this.props.page, 'CssClasses', []);

        const hostClasses = [styles.Renderer, ...pageClasses].join(' ');

        return (

            <div className={hostClasses}>
                <link
                    href={`${this.props.endPointUrl}/blob/${get(this.props.page, 'StyleSheetBlobID')}`}
                    rel="stylesheet"
                    id='makeup-style'
                />

                {this.props.page.Containers.map((container, containerIndex) => {
                    return <div key={containerIndex} className={container.CssClasses.join(' ')}> 
                        {container.Children.map((child, childIndex) => {
                            return <div key={'child-' + childIndex} className={child.CssClasses.join(' ')}> 
                                {child.Blocks.map((block, blockIndex) => {
                                    return <VisualBlock 
                                            context={this.props.context}
                                            block={block}
                                            components={this.components}
                                            key={'block-' + blockIndex} 
                                            data-block-index={blockIndex}
                                            onClick={(e) => this.elementClicked(e)}
                                        />
                                })}
                            </div>
                        })}
                     </div>
                })}
            </div>
        );
    }
}

export default withStyles(styles)(Renderer);

